
.. include:: ../../README.rst
   :end-before:  Installation

.. toctree::
   :hidden:
   :maxdepth: 1

   installation
   demo
   examples
   conversions
   api
   info

:doc:`API Reference <./api>`
------------------------------------------------

Documentation for the functions included in Oct2Py.


:doc:`Installation <./installation>`
------------------------------------------------

How to install Oct2Py.


:doc:`Examples <./examples>`
------------------------------------------------

Introductory examples.


:doc:`Type Conversions <./conversions>`
------------------------------------------------

Oct2Py data type conversions.


:doc:`Information <./info>`
-----------------------------------------

Other information about Oct2Py.
